import { Patch } from 'immer';
import { GenericObject } from './middleware.js';
import { Serializer } from './serializers.js';
import { Config, MappedConfig, Parameter } from './store.js';
import type { PartialDeep } from 'type-fest';
export declare const createSearch: (query: Record<string, string>) => string;
/**
 * Default skip implementation
 */
export declare function defaultSkipValue<V>(value?: V, initialValue?: V): boolean;
export declare function pm<V>(name: string, serializer: Serializer<V>, thisSkipValue?: (value?: V, initialValue?: V) => boolean): () => Parameter<V>;
export declare const createOrApplyPath: <T>(obj: GenericObject | null, path: readonly string[], value?: T | null) => GenericObject | null;
export declare const formatNamespace: (key: string, ns?: string) => string;
export declare const get: <T extends Record<string, unknown>>(object: T | null | undefined, path: ReadonlyArray<string | number>) => unknown;
/**
 * @return an object with the keys that have been processed
 * if a key has been removed / set to undefined, we still return it to
 * be able to create a diff to the current state
 */
export declare const createQueriesFromPatch: <T extends Record<string, unknown>>(config: Config, ns: string, patch: readonly Patch[], state: T, initialState: T) => object;
/**
 * Creates a queryObject that can be serialized.
 */
export declare const createQueryObject: <T extends Record<string, unknown>>(config: MappedConfig, ns: string, values: Partial<T> | PartialDeep<T>, initialState?: Partial<T> | PartialDeep<T> | null | undefined) => {};
export declare const applyDiffWithCreateQueriesFromPatch: <T extends Record<string, unknown>>(config: Config, ns: string, currentQuery: object, patch: readonly Patch[], state: T, initialState: T) => {};
/**
 * Applies the given queryValues to the current state, based on the configuration
 * Important: Mutates `state`.
 * @return an object with the keys that have been processed
 */
export declare const applyFlatConfigToState: <T extends Record<string, unknown>>(config: MappedConfig, queryValues: Record<string, string>, ns: string, state: T, initialState: T, apply?: boolean) => {};
/**
 * Creates a flat serializable object based on a mapping Object
 * that can be used to generate a query string.
 * @return a key/value object with the object containing the defined parameters as key.
 */
export declare const flattenConfig: (config: Config | readonly Config[], path?: readonly (string | number)[]) => MappedConfig;
